@@ -3,8 +3,8 @@
 #' Information of metal binding proteins is extracted from UniProt data retrieved with
 #' \code{fetch_uniprot} as well as QuickGO data retrieved with \code{fetch_quickgo}.
 #'
-#' @param data_uniprot a data frame containing at least the \code{ft_binding}, \code{cc_cofactor}
-#' and \code{cc_catalytic_activity} columns.
+#' @param data_uniprot a data frame containing at least the `ft_binding`, `cc_cofactor`,
+#' `cc_catalytic_activity` and `keyword` columns.
 #' @param data_quickgo a data frame containing molecular function gene ontology information for at
 #' least the proteins of interest. This data should be obtained by calling \code{fetch_quickgo()}.
 #' @param data_chebi optional, a data frame that can be manually obtained with \code{fetch_chebi(stars = c(2, 3))}.
@@ -36,13 +36,13 @@
 #' * \code{binding_mode}: Contains information about the way the amino acid residue interacts with the ligand. If it is
 #' "covalent" then the residue is not in contact with the metal directly but only the cofactor that binds the metal.
 #' * \code{metal_function}: Contains information about the function of the metal. E.g. "catalytic".
-#' * \code{metal_id_part}: Contains a ChEBI ID that identifiers the metal part of the ligand. This is always the metal atom.
+#' * \code{metal_id_part}: Contains a ChEBI ID that identifies the metal part of the ligand. This is always the metal atom.
 #' * \code{metal_id_part_name}: The name of the ID in the \code{metal_id_part} column. This information is based on
 #' ChEBI.
 #' * \code{note}: Contains notes associated with information based on cofactors.
 #' * \code{chebi_id}: Contains the original ChEBI IDs the information is based on.
-#' * \code{source}: Contains the sources of the information. This can consist of "binding", "cofactor", "catalytic_activity"
-#' and "go_term".
+#' * \code{source}: Contains the sources of the information. This can consist of "binding", "cofactor", "catalytic_activity",
+#' "Keyword" and "go_term".
 #' * \code{eco}: If there is evidence the annotation is based on it is annotated with an ECO ID, which is split by source.
 #' * \code{eco_type}: The ECO identifier can fall into the "manual_assertion" group for manually curated annotations or the
 #' "automatic_assertion" group for automatically generated annotations. If there is no evidence it is annotated as
@@ -54,6 +54,7 @@
 #' * \code{go_name}: Contains gene ontology names if there are any metal related ones associated with the annotation.
 #' * \code{assigned_by}: Contains information about the source of the gene ontology term assignment.
 #' * \code{database}: Contains information about the source of the ChEBI annotation associated with gene ontology terms.
+#' * `keyword`: Contains keywords if they were annotated in UniProt.
 #'
 #' For each protein identifier the data frame contains information on the bound ligand as well as on its position if it is known.
 #' Since information about metal ligands can come from multiple sources, additional information (e.g. evidence) is nested in the returned
@@ -66,7 +67,8 @@
 #' with the \code{"go_term"} source). Values of columns not relevant for a certain source should be replaced with \code{NA}.
 #' Since a \code{most_specific_id} can have multiple \code{chebi_id}s associated with it we need to unnest the \code{chebi_id}
 #' column and associated columns in which information is separated by "|". Afterwards evidence and additional information can be
-#' unnested by first splitting data for ";;" and then for ";".
+#' unnested by first splitting data for ";;" and then for ";". If the "metal_id_part_name" column contains an NA value the indicated
+#' ligand position does not directly contact the metal ion. This is usually the case for ligands such as e.g. heme.
 #' @import dplyr
 #' @import tidyr
 #' @import purrr
@@ -88,7 +90,8 @@
 #'   columns = c(
 #'     "ft_binding",
 #'     "cc_cofactor",
-#'     "cc_catalytic_activity"
+#'     "cc_catalytic_activity",
+#'     "keyword"
 #'   )
 #' )
 #'
@@ -130,11 +133,11 @@ extract_metal_binders <- function(data_uniprot,
   metal_go_slim_subset <- protti::metal_go_slim_subset
   # Check if required R packages are installed
   if (!requireNamespace("igraph", quietly = TRUE)) {
-    message("Package \"igraph\" is needed for this function to work. Please install it.", call. = FALSE)
+    message("Package \"igraph\" is needed for this function to work. Please install it.")
     return(invisible(NULL))
   }
   if (!requireNamespace("stringi", quietly = TRUE)) {
-    message("Package \"stringi\" is needed for this function to work. Please install it.", call. = FALSE)
+    message("Package \"stringi\" is needed for this function to work. Please install it.")
     return(invisible(NULL))
   }
 
@@ -154,8 +157,9 @@ extract_metal_binders <- function(data_uniprot,
   # data_uniprot
   if (!("ft_binding" %in% colnames(data_uniprot) &
     "cc_cofactor" %in% colnames(data_uniprot) &
+    "keyword" %in% colnames(data_uniprot) &
     "cc_catalytic_activity" %in% colnames(data_uniprot))) {
-    stop('Please include at least the columns "ft_binding", "cc_cofactor" and "cc_catalytic_activity" in "data_uniprot"!')
+    stop('Please include at least the columns "ft_binding", "cc_cofactor", "cc_catalytic_activity" and "keyword" in "data_uniprot"!')
   }
   # data_quickgo
   if (!("gene_product_db" %in% colnames(data_quickgo) &
@@ -652,6 +656,59 @@ extract_metal_binders <- function(data_uniprot,
     message("DONE ", paste0("(", round(as.numeric(difftime(Sys.time(), start_time, units = "secs")), digits = 2), "s)"))
   }
 
+  # Extract keyword information from UniProt
+  if (show_progress == TRUE) {
+    message("Extract keyword information from UniProt ... ", appendLF = FALSE)
+    start_time <- Sys.time()
+  }
+
+  # Define additional metal names that cannot be found just based on the metal name from the element list
+  additional_metal_names <- c("Metal-binding", "Metalloprotease", "2Fe-2S", "3Fe-4S", "4Fe-4S", "4Fe-4S", "Heme")
+
+  unlisted_metal_list <- metal_list %>%
+    dplyr::mutate(chebi_ion_id = stringr::str_split(.data$chebi_ion_id, pattern = ";")) %>%
+    tidyr::unnest("chebi_ion_id")
+
+  keyword_uniprot <- data_uniprot %>%
+    dplyr::distinct(.data$accession, .data$keyword) %>%
+    tidyr::drop_na("keyword") %>%
+    dplyr::mutate(keyword = stringr::str_split(
+      .data$keyword,
+      pattern = ";"
+    )) %>%
+    tidyr::unnest("keyword") %>%
+    dplyr::filter(.data$keyword %in% c(metal_list$name, additional_metal_names)) %>%
+    # annotate metal_id_part and chebi_id
+    dplyr::mutate(chebi_id = stats::setNames(metal_list$chebi_ion_id, metal_list$name)[.data$keyword]) %>%
+    dplyr::mutate(chebi_id = dplyr::case_when(
+      .data$keyword == "Metal-binding" ~ "25213",
+      .data$keyword == "Metalloprotease" ~ "60240",
+      .data$keyword == "2Fe-2S" ~ "190135",
+      .data$keyword == "3Fe-4S" ~ "47402",
+      .data$keyword == "4Fe-4S" ~ "49883",
+      .data$keyword == "Heme" ~ "30413",
+      TRUE ~ .data$chebi_id
+    )) %>%
+    dplyr::mutate(chebi_id = str_split(.data$chebi_id, pattern = ";")) %>%
+    tidyr::unnest("chebi_id") %>%
+    # Use the atom id if chebi ion ID is not present
+    dplyr::mutate(chebi_id = ifelse(is.na(.data$chebi_id),
+      stats::setNames(metal_list$chebi_id, metal_list$name)[.data$keyword],
+      .data$chebi_id
+    )) %>%
+    # first use uniprot data to directly annotate IDs that don't have a formula with the correct metal
+    dplyr::mutate(metal_id_part = stats::setNames(metal_chebi_uniprot$metal_atom_id, as.character(metal_chebi_uniprot$id))[.data$chebi_id]) %>%
+    # then use the metal_list to annotate the rest
+    dplyr::mutate(metal_id_part = ifelse(is.na(.data$metal_id_part),
+      stats::setNames(unlisted_metal_list$chebi_id, as.character(unlisted_metal_list$chebi_ion_id))[.data$chebi_id],
+      .data$metal_id_part
+    )) %>%
+    dplyr::mutate(source = "Keyword")
+
+  if (show_progress == TRUE) {
+    message("DONE ", paste0("(", round(as.numeric(difftime(Sys.time(), start_time, units = "secs")), digits = 2), "s)"))
+  }
+
   # Check if there are any metal containing entries that are not yet part of the ChEBI dataset provided by protti
   # This could be an indirect indication that some of the manually added ChEBI entries (without formula but metal related)
   # are also missing.
@@ -683,6 +740,8 @@ extract_metal_binders <- function(data_uniprot,
   }
 
   mf_quickgo <- data_quickgo %>%
+    # make sure to only take enabling IDs
+    dplyr::filter(.data$qualifier == "enables") %>%
     dplyr::filter(.data$gene_product_db == "UniProtKB" &
       .data$go_aspect == "molecular_function") %>%
     # The data that will be used for filtering is a dataset provided with protti
@@ -757,7 +816,7 @@ extract_metal_binders <- function(data_uniprot,
   }
 
   # Metal sub IDs
-  chebi_ids <- unique(c(b_uniprot$chebi_id, cofactor_uniprot$chebi_id, catalytic_activity_uniprot$chebi_id, mf_quickgo$chebi_id))
+  chebi_ids <- unique(c(b_uniprot$chebi_id, cofactor_uniprot$chebi_id, catalytic_activity_uniprot$chebi_id, mf_quickgo$chebi_id, keyword_uniprot$chebi_id))
   chebi_sub_id_mapping <- tibble::tibble(chebi_id = chebi_ids) %>%
     dplyr::mutate(chebi_sub_id = purrr::map_chr(find_all_subs(data_chebi_relation, .data$chebi_id, accepted_types = c("is_a", "is_conjugate_acid_of", "is_conjugate_base_of")),
       .f = ~ paste0(.x, collapse = ",")
@@ -767,14 +826,73 @@ extract_metal_binders <- function(data_uniprot,
     message("DONE ", paste0("(", round(as.numeric(difftime(Sys.time(), start_time, units = "secs")), digits = 2), "s)"))
   }
 
+  # Fix divalent metal cation (DMC) annotation in combination with Keywords
+  # Keywords are "metal_name cation" ChEBI IDs, meaning they cannot be combined with divalent metal cations
+  # Here we check which of the Keyword subterms is the divalent metal cation and combine it with the divalent metal cation annotation
+  if (show_progress == TRUE) {
+    message("Combine divalent metal cation with Keywords ... ", appendLF = FALSE)
+    start_time <- Sys.time()
+  }
+
+  dmc_chebi_sub_ids <- chebi_sub_id_mapping %>%
+    dplyr::filter(.data$chebi_id == "60240") %>%
+    dplyr::pull(.data$chebi_sub_id) %>%
+    stringr::str_split(pattern = ",") %>%
+    unlist()
+
+  keyword_combination <- dplyr::bind_rows(b_uniprot, cofactor_uniprot, catalytic_activity_uniprot, mf_quickgo, keyword_uniprot) %>%
+    dplyr::left_join(chebi_sub_id_mapping, by = "chebi_id") %>%
+    dplyr::mutate(is_keyword = .data$source == "Keyword") %>%
+    dplyr::group_by(.data$accession, .data$is_keyword) %>%
+    # non_keyword_is_DMC: check if the non keyword term contains DMC, while not containing any specific metal annotation
+    # dplyr::mutate(non_keyword_is_DMC = any(.data$chebi_id == "60240") & !any(.data$chebi_id != "60240" & .data$chebi_id != "25213") & !.data$is_keyword) %>%
+    # non_keyword_is_DMC: check if the non keyword term contains DMC
+    dplyr::mutate(non_keyword_is_DMC = any(.data$chebi_id == "60240") & !.data$is_keyword) %>%
+    # keyword_is_not_MC: check if the keyword is not just metal-binding
+    dplyr::mutate(keyword_is_not_MC = !all(.data$chebi_id == "25213" | .data$chebi_id == "60240") & .data$is_keyword) %>%
+    dplyr::group_by(.data$accession) %>%
+    dplyr::mutate(
+      has_keyword = any(.data$is_keyword),
+      non_keyword_is_DMC = any(.data$non_keyword_is_DMC),
+      keyword_is_not_MC = any(.data$keyword_is_not_MC)
+    ) %>%
+    # Filter for groups that contain a keyword but that do not only contain keywords and
+    # of which the non-keyword is DMC and otherwise unspecific and of which the keyword is not just metal-binding
+    dplyr::filter(all(.data$has_keyword & !all(.data$is_keyword) &
+      .data$non_keyword_is_DMC &
+      .data$keyword_is_not_MC)) %>%
+    dplyr::ungroup() %>%
+    # Filter so that only the non generic metal terms of keywords are left for the reannotation
+    dplyr::filter(.data$source == "Keyword" & !(.data$chebi_id == "25213" | .data$chebi_id == "60240")) %>%
+    dplyr::mutate(chebi_sub_id = ifelse(.data$chebi_sub_id == "", .data$chebi_id, .data$chebi_sub_id)) %>%
+    dplyr::mutate(split_sub_ids = stringr::str_split(.data$chebi_sub_id, pattern = ",")) %>%
+    dplyr::group_by(.data$accession) %>%
+    dplyr::mutate(chebi_id = unlist(ifelse(.data$is_keyword & .data$keyword != "Metal-binding",
+      map(
+        .x = .data$split_sub_ids,
+        .f = ~ .x[.x %in% dmc_chebi_sub_ids]
+      ),
+      .data$chebi_id
+    ))) %>%
+    dplyr::distinct(.data$accession, .data$chebi_id, .data$keyword) %>%
+    tidyr::drop_na("keyword") %>%
+    dplyr::rename("new_chebi_id" = "chebi_id")
+
+  if (show_progress == TRUE) {
+    message("DONE ", paste0("(", round(as.numeric(difftime(Sys.time(), start_time, units = "secs")), digits = 2), "s)"))
+  }
+
   # Combine data
   if (show_progress == TRUE) {
     message("Combine data ... ", appendLF = FALSE)
     start_time <- Sys.time()
   }
 
-  combined <- dplyr::bind_rows(b_uniprot, cofactor_uniprot, catalytic_activity_uniprot, mf_quickgo) %>%
+  combined <- dplyr::bind_rows(b_uniprot, cofactor_uniprot, catalytic_activity_uniprot, mf_quickgo, keyword_uniprot) %>%
     dplyr::left_join(chebi_sub_id_mapping, by = "chebi_id") %>%
+    dplyr::left_join(keyword_combination, by = c("accession", "keyword")) %>%
+    dplyr::mutate(chebi_id = dplyr::coalesce(.data$new_chebi_id, .data$chebi_id)) %>%
+    dplyr::select(-"new_chebi_id") %>%
     dplyr::mutate(chebi_sub_id = ifelse(.data$chebi_sub_id == "", .data$chebi_id, .data$chebi_sub_id)) %>%
     dplyr::mutate(most_specific_id = stringr::str_split(.data$chebi_sub_id, pattern = ",")) %>%
     dplyr::group_by(.data$accession) %>%
@@ -832,7 +950,8 @@ extract_metal_binders <- function(data_uniprot,
       go_term = paste0(stats::na.omit(.data$go_term), collapse = "|"),
       go_name = paste0(stats::na.omit(.data$go_name), collapse = "|"),
       assigned_by = paste0(stats::na.omit(.data$assigned_by), collapse = "|"),
-      database = paste0(stats::na.omit(.data$database), collapse = "|")
+      database = paste0(stats::na.omit(.data$database), collapse = "|"),
+      keyword = paste0(stats::na.omit(.data$keyword), collapse = "|")
     ) %>%
     dplyr::ungroup() %>%
     dplyr::filter(!.data$appears) %>%
@@ -917,7 +1036,8 @@ extract_metal_binders <- function(data_uniprot,
       go_term = ifelse(.data$go_term == "NA" | .data$go_term == "", NA, .data$go_term),
       go_name = ifelse(.data$go_name == "NA" | .data$go_name == "", NA, .data$go_name),
       assigned_by = ifelse(.data$assigned_by == "NA" | .data$assigned_by == "", NA, .data$assigned_by),
-      database = ifelse(.data$database == "NA" | .data$database == "", NA, .data$database)
+      database = ifelse(.data$database == "NA" | .data$database == "", NA, .data$database),
+      keyword = ifelse(.data$keyword == "NA" | .data$keyword == "", NA, .data$keyword)
     ) %>%
     dplyr::mutate(binding_temp_1 = stringr::str_split(.data$metal_id_part, pattern = ",")) %>%
     tidyr::unnest("binding_temp_1") %>%
@@ -955,6 +1075,7 @@ extract_metal_binders <- function(data_uniprot,
       go_name = paste0(.data$go_name, collapse = "||"),
       assigned_by = paste0(.data$assigned_by, collapse = "||"),
       database = paste0(.data$database, collapse = "||"),
+      keyword = paste0(.data$keyword, collapse = "||"),
       metal_id_part = paste0(unique(.data$metal_id_part), collapse = ","),
       metal_id_part_name = paste0(unique(.data$metal_id_part_name), collapse = ",")
     ) %>%
@@ -966,7 +1087,8 @@ extract_metal_binders <- function(data_uniprot,
       go_term = ifelse(.data$go_term == "NA" | .data$go_term == "", NA, .data$go_term),
       go_name = ifelse(.data$go_name == "NA" | .data$go_name == "", NA, .data$go_name),
       assigned_by = ifelse(.data$assigned_by == "NA" | .data$assigned_by == "", NA, .data$assigned_by),
-      database = ifelse(.data$database == "NA" | .data$database == "", NA, .data$database)
+      database = ifelse(.data$database == "NA" | .data$database == "", NA, .data$database),
+      keyword = ifelse(.data$keyword == "NA" | .data$keyword == "", NA, .data$keyword),
     ) %>%
     dplyr::mutate(
       metal_id_part_binding = ifelse(.data$metal_id_part_binding == "NA" | .data$metal_id_part_binding == "", NA, .data$metal_id_part_binding),
@@ -1028,7 +1150,8 @@ extract_metal_binders <- function(data_uniprot,
       "go_term",
       "go_name",
       "assigned_by",
-      "database"
+      "database",
+      "keyword"
     )
 
   if (show_progress == TRUE) {
