@@ -22,7 +22,7 @@
 #' @importFrom stats na.omit
 find_chebis <- function(chebi_data, pattern) {
   if (!requireNamespace("stringi", quietly = TRUE)) {
-    message("Package \"stringi\" is needed for this function to work. Please install it.", call. = FALSE)
+    message("Package \"stringi\" is needed for this function to work. Please install it.")
     return(invisible(NULL))
   }
   data <- chebi_data %>%
