@@ -178,7 +178,7 @@ fit_drc_4p <- function(data,
                        include_models = FALSE,
                        retain_columns = NULL) {
   if (!requireNamespace("drc", quietly = TRUE)) {
-    message("Package \"drc\" is needed for this function to work. Please install it.", call. = FALSE)
+    message("Package \"drc\" is needed for this function to work. Please install it.")
     return(invisible(NULL))
   }
   # to prevent no visible binding for global variable '.' note.
