@@ -10,34 +10,34 @@
 #' @param peptide_data a data frame that contains the input columns to this function. If structure
 #' or prediction files should be fetched automatically, please provide column names to the following
 #' arguments: **uniprot_id**, **pdb_id**, **chain**, **auth_seq_id**,
-#' **map_value**. If no PDB structure for a protein is available the \code{pdb_id} and \code{chain}
+#' **map_value**. If no PDB structure for a protein is available the `pdb_id` and `chain`
 #' column should contain NA at these positions. If a structure or prediction file is provided in the
-#' \code{structure_file} argument, this data frame should only contain information associated with
+#' `structure_file` argument, this data frame should only contain information associated with
 #' the provided structure. In case of a user provided structure, column names should be provided to
 #' the following arguments: **uniprot_id**, **chain**, **auth_seq_id**, **map_value**.
-#' @param uniprot_id a character column in the \code{peptide_data} data frame that contains UniProt
+#' @param uniprot_id a character column in the `peptide_data` data frame that contains UniProt
 #' identifiers for a corresponding peptide, protein region or amino acid.
-#' @param pdb_id a character column in the \code{peptide_data} data frame that contains PDB
+#' @param pdb_id a character column in the `peptide_data` data frame that contains PDB
 #' identifiers for structures in which a corresponding peptide, protein region or amino acid is found.
 #' If a protein prediction should be fetched from AlphaFold, this column should contain NA. This
-#' column is not required if a structure or prediction file is provided in the \code{structure_file}
+#' column is not required if a structure or prediction file is provided in the `structure_file`
 #' argument.
-#' @param chain a character column in the \code{peptide_data} data frame that contains the name of
+#' @param chain a character column in the `peptide_data` data frame that contains the name of
 #' the chain from the PDB structure in which the peptide, protein region or amino acid is found.
 #' If a protein prediction should be fetched from AlphaFold, this column should contain NA. If an
-#' AlphaFold prediction is provided to the \code{structure_file} argument the chain should be
+#' AlphaFold prediction is provided to the `structure_file` argument the chain should be
 #' provided as usual (All AlphaFold predictions only have chain A). **Important:** please provide
 #' the author defined chain definitions for both ".cif" and ".pdb" files. When the output of the
-#' \code{find_peptide_in_structure} function is used as the input for this function, this
-#' corresponds to the \code{auth_asym_id} column.
-#' @param auth_seq_id optional, a character (or numeric) column in the \code{peptide_data} data frame
+#' `find_peptide_in_structure` function is used as the input for this function, this
+#' corresponds to the `auth_asym_id` column.
+#' @param auth_seq_id a character (or numeric) column in the `peptide_data` data frame
 #' that contains semicolon separated positions of peptides, protein regions or amino acids in the
-#' corresponding PDB structure or AlphaFold prediction. This information can be obtained from the
-#' \code{find_peptide_in_structure} function. The corresponding column in the output is called
-#' \code{auth_seq_id}. In case of AlphaFold predictions, UniProt positions should be used. If
-#' signal positions and not stretches of amino acids are provided, the column can be numeric and
-#' does not need to contain the semicolon separator.
-#' @param map_value a numeric column in the \code{peptide_data} data frame that contains a value
+#' corresponding PDB structure or AlphaFold prediction. Can be `NA` for rows that should not be mapped.
+#' This information can be obtained from the `find_peptide_in_structure` function. The corresponding
+#' column in the output is called `auth_seq_id`. In case of AlphaFold predictions, UniProt positions
+#' should be used. If signal positions and not stretches of amino acids are provided, the column
+#' can be numeric and does not need to contain the semicolon separator.
+#' @param map_value a numeric column in the `peptide_data` data frame that contains a value
 #' associated with each peptide, protein region or amino acid. If one start to end position pair
 #' has multiple different map values, the maximum will be used. This value will be displayed as a
 #' colour gradient when mapped onto the structure. The value can for example be the fold change,
@@ -47,13 +47,20 @@
 #' in the structure that do not map any selection receive a value of 0. If an amino acid position
 #' is associated with multiple mapped values, e.g. from different peptides, the maximum mapped
 #' value will be displayed.
+#' @param baseline_map_value optional, a numeric value defining the baseline of the
+#' `map_value`. If, for a given structure or protein or the whole dataset (`scale_per_structure = FALSE`),
+#' all mapped values are equal to this baseline, the scaled values are set to 50, which is the lower
+#' bound of the scaling range. If not provided, constant values are scaled to 100, which is the upper bound.
 #' @param file_format a character vector containing the file format of the structure that will be
-#' fetched from the database for the PDB identifiers provided in the \code{pdb_id} column. This
-#' can be either ".cif" or ".pdb". The default is \code{".cif"}. We recommend using ".cif" files
+#' fetched from the database for the PDB identifiers provided in the `pdb_id` column. This
+#' can be either ".cif" or ".pdb". The default is `".cif"`. We recommend using ".cif" files
 #' since every structure contains a ".cif" file but not every structure contains a ".pdb" file.
 #' Fetching and mapping onto ".cif" files takes longer than for ".pdb" files. If a structure file
-#' is provided in the \code{structure_file} argument, the file format is detected automatically
+#' is provided in the `structure_file` argument, the file format is detected automatically
 #' and does not need to be provided.
+#' @param alphafold_version a character value that specifies the alphafold version that should be
+#' used. This is regularly updated by the database. We always try to make the current version the
+#' default version. Available version can be found here: https://ftp.ebi.ac.uk/pub/databases/alphafold/
 #' @param scale_per_structure a logical value that specifies if scaling should be performed for
 #' each structure independently (TRUE) or over the whole data set (FALSE). The default is TRUE,
 #' which scales the scores of each structure independently so that each structure has a score
@@ -63,13 +70,13 @@
 #' saved in the current working directory. The location should be provided in the following
 #' format "folderA/folderB".
 #' @param structure_file optional, a character argument specifying the path to the location and
-#' name of a structure file in ".cif" or ".pdb" format. If a structure is provided the \code{peptide_data}
+#' name of a structure file in ".cif" or ".pdb" format. If a structure is provided the `peptide_data`
 #' data frame should only contain mapping information for this structure.
-#' @param show_progress a logical, if \code{show_progress = TRUE}, a progress bar will be shown
+#' @param show_progress a logical, if `show_progress = TRUE`, a progress bar will be shown
 #' (default is TRUE).
 #'
 #' @return The function exports a modified ".pdb" or ".cif" structure file. B-factors have been
-#' replaced with scaled (50-100) values provided in the \code{map_value} column.
+#' replaced with scaled (50-100) values provided in the `map_value` column.
 #' @import dplyr
 #' @import tidyr
 #' @import progress
@@ -136,7 +143,9 @@ map_peptides_on_structure <- function(peptide_data,
                                       chain,
                                       auth_seq_id,
                                       map_value,
+                                      baseline_map_value = NULL,
                                       file_format = ".cif",
+                                      alphafold_version = "v6",
                                       scale_per_structure = TRUE,
                                       export_location = NULL,
                                       structure_file = NULL,
@@ -152,6 +161,9 @@ map_peptides_on_structure <- function(peptide_data,
     export_location <- paste0(export_location, "/")
   }
 
+  # Check if the user provided a baseline
+  baseline_provided <- !missing(baseline_map_value)
+
   # What to do if no structure file was provided:
   if (missing(structure_file)) {
     if (!curl::has_internet()) {
@@ -176,16 +188,24 @@ map_peptides_on_structure <- function(peptide_data,
         {{ auth_seq_id }},
         {{ map_value }}
       ) %>%
+      dplyr::mutate(id_for_scaling = ifelse(is.na({{ pdb_id }}), {{ uniprot_id }}, {{ pdb_id }})) %>%
+      # for AF predictions this still needs an ID to properly work
       dplyr::mutate(scaling_info = ifelse(rep(scale_per_structure, dplyr::n()),
-                                          {{ pdb_id }},
+                                          .data$id_for_scaling,
                                           "scale_overall")) %>%
       # determines if scores should by scaled by structure or
       # one scale for the whole data set.
       dplyr::group_by(.data$scaling_info) %>%
+      dplyr::mutate(all_baseline = (
+        baseline_provided &&
+          dplyr::n_distinct({{ map_value }}, na.rm = TRUE) == 1 &&
+          dplyr::first({{ map_value }}) == baseline_map_value
+      )) %>%
       dplyr::mutate({{ map_value }} := round(
-        scale_protti(c({{ map_value }}), method = "01") * 50 + 50,
+        scale_protti(c({{ map_value }}), method = "01", default_to_high = !dplyr::first(.data$all_baseline)) * 50 + 50,
         digits = 2
       )) %>%
+      dplyr::select(-"all_baseline") %>%
       # Scale values between 50 and 100
       group_by({{ uniprot_id }}, {{ pdb_id }}, {{ chain }}, {{ auth_seq_id }}) %>%
       dplyr::mutate(residue_internal = stringr::str_split({{ auth_seq_id }}, pattern = ";")) %>%
@@ -223,7 +243,7 @@ map_peptides_on_structure <- function(peptide_data,
         dplyr::distinct({{ pdb_id }}, {{ uniprot_id }}) %>%
         dplyr::group_by({{ pdb_id }}) %>%
         dplyr::mutate(name = paste({{ uniprot_id }}, collapse = "_")) %>%
-        dplyr::mutate(name = ifelse(nchar(.data$name) >= 240,
+        dplyr::mutate(name = ifelse(nchar(.data$name) >= 50,
                                     paste0(stringr::str_count(.data$name, pattern = "_") + 1, "_proteins"),
                                     .data$name
                                     )
@@ -353,7 +373,7 @@ map_peptides_on_structure <- function(peptide_data,
       if (file_format == ".cif") {
         batches <- purrr::map(
           .x = uniprot_ids,
-          .f = ~ paste0("https://alphafold.ebi.ac.uk/files/AF-", .x, "-F1-model_v3.cif")
+          .f = ~ paste0("https://alphafold.ebi.ac.uk/files/AF-", .x, "-F1-model_", alphafold_version, ".cif")
         )
 
         names(batches) <- paste0(uniprot_ids, "_AlphaFold")
@@ -397,7 +417,7 @@ map_peptides_on_structure <- function(peptide_data,
         # same as above but for .pdb files. Indexing is different.
         batches <- purrr::map(
           .x = uniprot_ids,
-          .f = ~ paste0("https://alphafold.ebi.ac.uk/files/AF-", .x, "-F1-model_v3.pdb")
+          .f = ~ paste0("https://alphafold.ebi.ac.uk/files/AF-", .x, "-F1-model_", alphafold_version, ".pdb")
         )
 
         names(batches) <- paste0(uniprot_ids, "_AlphaFold")
@@ -584,8 +604,14 @@ map_peptides_on_structure <- function(peptide_data,
     peptide_data_filter <- peptide_data %>%
       dplyr::ungroup() %>%
       dplyr::distinct({{ uniprot_id }}, {{ chain }}, {{ auth_seq_id }}, {{ map_value }}) %>%
-      dplyr::mutate({{ map_value }} := round(scale_protti(c({{ map_value }}), method = "01") * 50 + 50, digits = 2)) %>%
+      dplyr::mutate(all_baseline = (
+        baseline_provided &&
+          dplyr::n_distinct({{ map_value }}, na.rm = TRUE) == 1 &&
+          dplyr::first({{ map_value }}) == baseline_map_value
+      )) %>%
       # Scale values between 50 and 100
+      dplyr::mutate({{ map_value }} := round(scale_protti(c({{ map_value }}), method = "01", default_to_high = !dplyr::first(.data$all_baseline)) * 50 + 50, digits = 2)) %>%
+      dplyr::select(-"all_baseline") %>%
       group_by({{ chain }}, {{ auth_seq_id }}) %>%
       dplyr::mutate(residue_internal = ifelse(!is.na({{ auth_seq_id }}),
                                      stringr::str_split({{ auth_seq_id }}, pattern = ";"),
@@ -619,8 +645,12 @@ for the mapping. Make sure to provide a chain identifier if a mapping should be
         dplyr::mutate(
           # extract b-factor values based on positions
           b_factor = stringr::str_extract_all(.data$atoms, "[\\w[:punct:]]+[:space:]+")[[1]][15],
-          chain = stringr::str_extract_all(.data$atoms, "[\\w[:punct:]]+")[[1]][19],
-          residue_internal = suppressWarnings(stringr::str_extract_all(.data$atoms, "[\\w[:punct:]]+")[[1]][17])
+          chain = ifelse(length(stringr::str_extract_all(.data$atoms, "[\\w[:punct:]]+")[[1]]) == 21, # test if AF prediction
+                         stringr::str_extract_all(.data$atoms, "[\\w[:punct:]]+")[[1]][19],
+                         stringr::str_extract_all(.data$atoms, "[\\w[:punct:]]+")[[1]][17]),
+          residue_internal = ifelse(length(stringr::str_extract_all(.data$atoms, "[\\w[:punct:]]+")[[1]]) == 21,  # test if AF prediction
+                                    suppressWarnings(stringr::str_extract_all(.data$atoms, "[\\w[:punct:]]+")[[1]][17]),
+                                    suppressWarnings(stringr::str_extract_all(.data$atoms, "[\\w[:punct:]]+")[[1]][16]))
         ) %>%
         dplyr::ungroup() %>%
         dplyr::mutate(b_factor = stringr::str_replace(.data$b_factor, pattern = "\\.", replacement = "\\\\\\.")) %>%
