@@ -20,9 +20,9 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
   test_that("find_peptide_in_structure works", {
     expect_is(positions_structure, "data.frame")
     # test if position structure is in certain range as db can be updated
-    expect_gte(nrow(positions_structure), 569)
-    expect_lte(nrow(positions_structure), 700)
-    expect_equal(ncol(positions_structure), 17)
+    expect_gte(nrow(positions_structure), 650)
+    expect_lte(nrow(positions_structure), 800)
+    expect_equal(ncol(positions_structure), 20)
   })
 
   positions_structure_filter <- positions_structure %>%
@@ -74,7 +74,7 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
     expect_gt(file.info(paste0(tempdir(), "/2EL9_P60906.pdb"))$size, 900000)
     expect_gt(file.info(paste0(tempdir(), "/P37648_AlphaFold.pdb"))$size, 300000)
 
-    file_pdb_6UU2_P0A8T7 <- readr::read_tsv(paste0(tempdir(), "/2EL9_P60906.pdb"), col_names = FALSE, show_col_types = FALSE, progress = FALSE) %>%
+    file_pdb_2EL9_P60906 <- readr::read_tsv(paste0(tempdir(), "/2EL9_P60906.pdb"), col_names = FALSE, show_col_types = FALSE, progress = FALSE) %>%
       dplyr::mutate(atoms = ifelse(stringr::str_detect(.data$X1, pattern = "^ATOM|^HETATM"), .data$X1, NA)) %>%
       dplyr::mutate(
         chain = stringr::str_sub(.data$atoms, start = 22, end = 22),
@@ -84,7 +84,7 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
       dplyr::filter(residue %in% c(50, 55) & chain == "A") %>%
       dplyr::distinct(b_factor, residue, chain)
 
-    expect_equal(file_pdb_6UU2_P0A8T7$b_factor, c("     0", "   100"))
+    expect_equal(file_pdb_2EL9_P60906$b_factor, c("     0", "   100"))
 
     # .cif structure file provided
     positions_structure_filter_provided <- positions_structure_filter %>%
@@ -138,7 +138,7 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
     expect_equal(nrow(contact_maps[["6NPF"]]), 504)
     expect_equal(nrow(contact_maps[["1C14"]]), 18553)
     expect_equal(ncol(contact_maps[["P62942"]]), 18)
-    expect_equal(nrow(contact_maps[["P62942"]]), 111)
+    expect_equal(nrow(contact_maps[["P62942"]]), 110)
 
     # .cif structure file provided
 
